@@ -22,6 +22,7 @@ from lizard_map.models import WorkspaceItem
 from lizard_map.models import WorkspaceCollage
 from lizard_map.models import WorkspaceCollageSnippet
 from lizard_map.models import WorkspaceCollageSnippetGroup
+from lizard_map.utility import short_string
 from lizard_map.workspace import WorkspaceManager
 
 # Workspace stuff
@@ -415,6 +416,7 @@ def session_collage_snippet_add(request,
     """finds session user workspace and add snippet to (only) corresponding
     collage
     """
+
     if workspace_item_id is None:
         workspace_item_id = request.POST.get('workspace_item_id')
     if workspace_item_location_identifier is None:
@@ -435,6 +437,12 @@ def session_collage_snippet_add(request,
         workspace.collages.create()
     collage = workspace.collages.all()[0]
 
+    # Shorten name to 80 characters
+    workspace_item_location_shortname = short_string(
+        workspace_item_location_shortname, 80)
+    workspace_item_location_name = short_string(
+        workspace_item_location_name, 80)
+
     # create snippet using collage function: also finds/makes snippet group
     snippet, _ = collage.get_or_create_snippet(
         workspace_item=workspace_item,
@@ -545,7 +553,7 @@ def snippet_edit(request, snippet_id):
     if 'layout' in identifier:
         del identifier['layout']
     identifier.update({'layout': layout})
-    # print identifier
+
     snippet.set_identifier(identifier)
     snippet.save()
 
@@ -755,9 +763,12 @@ def export_snippet_group_statistics_csv(request, snippet_group_id=None):
     response = HttpResponse(mimetype='text/csv')
     response['Content-Disposition'] = 'attachment; filename=export.csv'
     writer = csv.writer(response)
-    colnames = ['min', 'max', 'avg', 'count_lt', 'count_gte',
+    colnames = ['min', 'max', 'avg', 'count_lt',
+                'count_gte',
                 'percentile', 'percentile_75']
-    colnamesdisplay = ['min', 'max', 'avg', '< boundary', '>= boundary',
+    colnamesdisplay = ['min', 'max', 'avg',
+                       '# < %s' % snippet_group.boundary_value,
+                       '# >= %s' % snippet_group.boundary_value,
                        'percentile_25', 'percentile_75']
     writer.writerow(colnamesdisplay)
     for row in statistics:
